@@ -63,17 +63,17 @@ extern "C" {
 
 #ifndef DOXYGEN_IGNORE
 /* libltc version */
-#define LIBLTC_VERSION "1.2.0"
+#define LIBLTC_VERSION "1.3.1"
 #define LIBLTC_VERSION_MAJOR  1
-#define LIBLTC_VERSION_MINOR  2
-#define LIBLTC_VERSION_MICRO  0
+#define LIBLTC_VERSION_MINOR  3
+#define LIBLTC_VERSION_MICRO  1
 
 /* interface revision number
  * http://www.gnu.org/software/libtool/manual/html_node/Updating-version-info.html
  */
-#define LIBLTC_CUR 11
-#define LIBLTC_REV  4
-#define LIBLTC_AGE  0
+#define LIBLTC_CUR 12
+#define LIBLTC_REV  0
+#define LIBLTC_AGE  1
 #endif /* end DOXYGEN_IGNORE */
 
 /**
@@ -277,7 +277,7 @@ typedef struct LTCFrame LTCFrame;
 /**
  * Extended LTC frame - includes audio-sample position offsets, volume, etc
  *
- * Note: For TV systems, the sample in the LTC audio data stream where the LTC Frame starts is not neccesarily at the same time
+ * Note: For TV systems, the sample in the LTC audio data stream where the LTC Frame starts is not necessarily at the same time
  * as the video-frame which is described by the LTC Frame.
  *
  * \ref off_start denotes the time of the first transition of bit 0 in the LTC frame.
@@ -539,6 +539,26 @@ void ltc_encoder_set_timecode(LTCEncoder *e, SMPTETimecode *t);
  */
 void ltc_encoder_get_timecode(LTCEncoder *e, SMPTETimecode *t);
 
+/**
+* Set the user-bits of the frame to the given data.
+*
+* The data should be a 32-bits unsigned integer.
+* It is written LSB first continiously int the eight user fields.
+*
+* @param e encoder handle
+* @param data the data to write
+*/
+void ltc_encoder_set_user_bits(LTCEncoder *e, unsigned long data);
+
+/**
+* Get a 32-bits unsigned integer from the user-data bits.
+* The data should be written LSB first in the frame
+*
+* @param e encoder handle
+*/
+
+unsigned long ltc_frame_get_user_bits(LTCFrame *f);
+
 /**
  * Move the encoder to the next timecode frame.
  * uses \ref ltc_frame_increment() internally.
@@ -674,7 +694,7 @@ int ltc_encoder_set_bufsize(LTCEncoder *e, double sample_rate, double fps);
  * typically LTC is sent at 0dBu ; in EBU callibrated systems that
  * corresponds to -18dBFS. - by default libltc creates -3dBFS
  *
- * since libltc generated 8bit audio-data, the minium dBFS
+ * since libltc generated 8bit audio-data, the minimum dBFS
  * is about -42dB which corresponds to 1 bit.
  *
  * 0dB corresponds to a signal range of 127
